@@ -276,6 +276,14 @@ main (int argc, char *argv[])
 
   g_unsetenv ("GIO_USE_VFS");
 
+  /* By default, libhandy reads settings from the Settings portal, which causes
+   * the portal to be started, which causes gnome-keyring to be started. This
+   * interferes with our attempt below to manually start gnome-keyring and set
+   * the login keyring password to a well-known value, which we overwrite with
+   * the user's password once they choose one.
+   */
+  g_setenv ("HDY_DISABLE_PORTAL", "1", /* overwrite */ TRUE);
+
   context = g_option_context_new (_("— GNOME initial setup"));
   g_option_context_add_main_entries (context, entries, NULL);
 
